.. _motor_machine_data:

Motor Data
----------

.. csv-table:: Valid data entries for the Motor class and group classification
    :header: "Motor", "Entry", "Group"
    :widths: 60, 60, 20

    "Normal Torque AC Motor", "`normal torque ac`", 1
    "Ring Cage AC Motor", "`ring cage ac`", 1
    "Synchronous AC Motor", "`synchronous ac`", 1
    "Phase Division AC Motor", "`phase division ac`", 1
    "Derivation DC Motor", "`derivation dc`", 1
    "Multiple Cylinders Combustion Engine", "`multiple cylinders combustion`", 1
    "High Torque AC Motor", "`high torque ac`", 2
    "High Slipping AC Motor", "`high slipping ac`", 2
    "Repulsion Induction AC Motor", "`repulsion induction ac`", 2
    "Monophasic AC Motor", "`monophasic ac`", 2
    "Series Winding DC Motor", "`series winding dc`", 2
    "Collector Rings AC Motor", "`collector rings ac`", 2
    "Mixed Winding DC Motor", "`mixed winding dc`", 2
    "Single Cylinder Combustion Engine", "`single cylinder combustion`", 2
    "Transmission Axle", "`transmission axle`", 2
    "Clutch", "`clutch`", 2

Machine Data
------------

.. csv-table:: Valid data entries for the Machine class and group classification
    :header: "Machine", "Entry", "Group"
    :widths: 60, 60, 20

    "Stirrer", "`stirrer`", 1
    "Small Blower", "`small blower`", 1
    "Exhaustor", "`exhaustor`", 1
    "Centrifugal Pump", "`centrifugal pump`", 1
    "Regular Compressor", "`regular compressor`", 1
    "Light Conveyor Belt", "`light conveyor belt`", 1
    "Heavy Conveyor Belt", "`heavy conveyor belt`", 2
    "Large Blower", "`large blower`", 2
    "Generator", "`generator`", 2
    "Transmission Axle", "`transmission axle`", 2
    "Laundry Machine", "`laundry machine`", 2
    "Press", "`press`", 2
    "Graphical Machine", "`graphical machine`", 2
    "Positive Displacement Pump", "`positive displacement pump`", 2
    "Sieving Machine", "`sieving machine`", 2
    "Pottery Machine", "`pottery machine`", 3
    "Bucket Elevator", "`bucket elevator`", 3
    "Reciprocating Compressor", "`reciprocating compressor`", 3
    "Mill", "`mill`", 3
    "Carpentry Machine", "`carpentry machine`", 3
    "Textile Machine", "`textile machine`", 3
    "Crusher", "`crusher`", 4
    "Crane", "`crane`", 4
    "Tire Shop Machine", "`tire shop machine`", 4